@@ -18,8 +18,7 @@ import socket
 import logging
 
 from apscheduler.schedulers.background import BackgroundScheduler
-from apscheduler.util import obj_to_ref
-from apscheduler.util import ref_to_obj
+from apscheduler.util import obj_to_ref, ref_to_obj, undefined
 from flask import Flask
 from .exceptions import ConfigurationError
 from .views import get_job
@@ -37,6 +36,7 @@ class APScheduler(object):
         self.__scheduler = scheduler or BackgroundScheduler()
         self.__allowed_hosts = ['*']
         self.__host_name = socket.gethostname().lower()
+        self.__views_enabled = False
 
         if app:
             self.init_app(app)
@@ -71,7 +71,9 @@ class APScheduler(object):
 
         self.__load_config(app)
         self.__load_jobs(app)
-        self.__load_views(app)
+
+        if self.__views_enabled:
+            self.__load_views(app)
 
     def start(self):
         """Starts the scheduler."""
@@ -119,9 +121,8 @@ class APScheduler(object):
 
         self.__scheduler.configure(**options)
 
-        hosts = app.config.get('SCHEDULER_ALLOWED_HOSTS')
-        if hosts:
-            self.__allowed_hosts = hosts
+        self.__allowed_hosts = app.config.get('SCHEDULER_ALLOWED_HOSTS', self.__allowed_hosts)
+        self.__views_enabled = app.config.get('SCHEDULER_VIEWS_ENABLED', self.__views_enabled)
 
     def __load_jobs(self, app):
         """Loads the job definitions from the Flask configuration."""
@@ -167,12 +168,20 @@ class APScheduler(object):
         if not trigger:
             raise ConfigurationError('Job %s is missing the parameter trigger.' % id)
 
-        trigger_type = trigger.pop('type', 'date')
-
-        func_args = job.get('args')
-        func_kwargs = job.get('kwargs')
-
-        job = self.__scheduler.add_job(call_func, trigger_type, func_args, func_kwargs, id, name, **trigger)
+        job = self.__scheduler.add_job(call_func,
+                                       trigger.pop('type', 'date'),
+                                       job.get('args'),
+                                       job.get('kwargs'),
+                                       id,
+                                       name,
+                                       job.get('misfire_grace_time', undefined),
+                                       job.get('coalesce', undefined),
+                                       job.get('max_instances', undefined),
+                                       job.get('next_run_time', undefined),
+                                       job.get('jobstore', 'default'),
+                                       job.get('executor', 'default'),
+                                       job.get('replace_existing', False),
+                                       **trigger)
         job.func_ref = func_ref
 
     @staticmethod
